@@ -724,7 +724,7 @@ static const char *parse_layout_coordinate (const char *fmt, int *val,
 		const int max)
 {
 	long v;
-	const char *e;
+	const char *e = fmt;
 
 	if (!strncasecmp(fmt, "FILL", sizeof("FILL") - 1)) {
 		*val = LAYOUT_SIZE_FILL;
@@ -901,7 +901,7 @@ static char *make_menu_title (const char *plist_title,
 	char *title = xstrdup (plist_title);
 	
 	if (!made_from_tags) {
-		if (!full_path) {
+		if (!full_path && !is_url(title)) {
 
 			/* Use only the file name instead of the full path. */
 			char *slash = strrchr (title, '/');
