@@ -428,12 +428,12 @@ int plist_find_del_fname (const struct plist *plist, const char *file)
 
 static char *title_expn_subs(char fmt, const struct file_tags *tags)
 {
-	static char track[10];
+	static char track[16];
 	
 	switch (fmt) {
 		case 'n':
 			if (tags->track != -1) {
-				sprintf (track, "%d", tags->track);
+				snprintf (track, sizeof(track), "%d", tags->track);
 				return track;
 			}
 			return NULL;
@@ -470,7 +470,7 @@ static void do_title_expn (char *dest, int size, const char *fmt,
 			 * format: %(x:true:false)
 			 */
 			if (*fmt == '(') {
-				char separator, expr[100];
+				char separator, expr[256];
 				int expr_pos = 0;
 
 				check_zero(*++fmt);
@@ -563,7 +563,7 @@ static void do_title_expn (char *dest, int size, const char *fmt,
 /* Build file title from struct file_tags. Returned memory is malloc()ed. */
 char *build_title (const struct file_tags *tags)
 {
-	char title[100];
+	char title[512];
 
 	do_title_expn (title, sizeof(title), options_get_str("FormatString"),
 			tags);
